Views
=========================

API Views
----------------------------------------

.. automodule:: kubernetes_manager.views.model_views
  :members:
  :undoc-members:
  :show-inheritance:

.. automodule:: kubernetes_manager.views.func_views
  :members:
  :undoc-members:
  :show-inheritance:
